(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     48377,       1355]*)
(*NotebookOutlinePosition[    131933,       4185]*)
(*  CellTagsIndexPosition[    131889,       4181]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Testing Wick's theorem
(C) Rok Zitko, rok.zitko@ijs.si, 2006\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< "\<../sneg.m\>"\)], "Input"],

Cell[BoxData[
    \("sneg $Id: sneg.m,v 1.66 2006/07/14 10:43:56 rok Exp rok $"\)], "Print"],

Cell[BoxData[
    \("Copyright (C) 2006 Rok Zitko, rok.zitko@ijs.si"\)], "Print"],

Cell[BoxData[
    \("sneg.m $Id: sneg.m,v 1.66 2006/07/14 10:43:56 rok Exp rok $ \
loaded"\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(<< Utilities`Notation`\)], "Input"],

Cell["\<\
Note: a number of functions, such as number[], depend on the fact that the \
last index is the spin index. Therefore the channel index must come before \
the spin index!\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", 
        RowBox[{
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(c\_\(k_, \(\(\[Alpha]_\)\(\[UpArrow]\)\)\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[1, k_, \[Alpha]_, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(c\_\(k_, \(\(\[Alpha]_\)\(\[DownArrow]\)\)\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[1, k_, \[Alpha]_, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              
              TagBox[\(c\_\(k_, \
\(\(\[Alpha]_\)\(\[UpArrow]\)\)\)\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[0, k_, \[Alpha]_, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              
              TagBox[\(c\_\(k_, \
\(\(\[Alpha]_\)\(\[DownArrow]\)\)\)\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[0, k_, \[Alpha]_, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(c\_\(k_, \[Alpha]_, \[Sigma]_\)\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[0, k_, \[Alpha]_, \[Sigma]_]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(c\_\(k_, \[Alpha]_, \[Sigma]_\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(c[1, k_, \[Alpha]_, \[Sigma]_]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(d\_\(k_, \(\(\[Alpha]_\)\(\[UpArrow]\)\)\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(d[1, k_, \[Alpha]_, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(d\_\(k_, \(\(\[Alpha]_\)\(\[DownArrow]\)\)\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(d[1, k_, \[Alpha]_, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              
              TagBox[\(d\_\(k_, \
\(\(\[Alpha]_\)\(\[UpArrow]\)\)\)\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(d[0, k_, \[Alpha]_, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              
              TagBox[\(d\_\(k_, \
\(\(\[Alpha]_\)\(\[DownArrow]\)\)\)\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(d[0, k_, \[Alpha]_, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(d\_\(k_, \[Alpha]_, \[Sigma]_\)\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(d[0, k_, \[Alpha]_, \[Sigma]_]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(d\_\(k_, \[Alpha]_, \[Sigma]_\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(d[1, k_, \[Alpha]_, \[Sigma]_]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[UpArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[1, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[DownArrow]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[1, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[UpArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[0, 1]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[DownArrow]\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[0, 0]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[Sigma]_\^\[Dagger]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[0, \[Sigma]_]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(a\_\[Sigma]_\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(a[1, \[Sigma]_]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Notation", "[", 
            RowBox[{
              TagBox[\(\(\[Therefore]\)\(\(a_\)\(\[Therefore]\)\)\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], " ", 
              "\[DoubleLongLeftRightArrow]", " ", 
              TagBox[\(dd[a_]\),
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"InfixNotation", "[", 
            RowBox[{
              TagBox["\[CenterDot]",
                NotationBoxTag,
                TagStyle->"NotationTemplateStyle"], ",", "nc"}], "]"}], ";"}],
         ")"}], ";"}]], "Input"],

Cell[BoxData[{
    \(\(snegfermionoperators[a, c, d];\)\), "\[IndentingNewLine]", 
    \(snegrealconstants[U, t]\), "\[IndentingNewLine]", 
    \(snegrealconstants[x]\  (*\ Actually, \ 
      this\ is\ a\ coordinate\ *) \), "\[IndentingNewLine]", 
    \(snegcomplexconstants[V]\)}], "Input"],

Cell[BoxData[
    \(\(Off[General::spell1];\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      It\ is\ important\ not\ to\ have\ interfering\ \(\(indeces\ !!\)!\)\ \
*) \)\(\[IndentingNewLine]\)\(snegfreeindexes[k, k1, k2, k3, k4, 
      kp, \[Sigma], \[Tau]]\[IndentingNewLine]
    snegfreeindexes[\[Alpha], \[Alpha]1, \[Alpha]2, \[Alpha]3, \[Alpha]4, \
\[Alpha]p]\[IndentingNewLine]
    snegfreeindexes[\[Beta]]\)\)\)], "Input"],

Cell["Note: O=:O:+<O>", "Text"],

Cell[BoxData[{
    \(\(\(acmt[
          c, {i1_, k1_, \[Alpha]1_, sp1_}, {i2_, k2_, \[Alpha]2_, 
            sp2_}] := \[IndentingNewLine]If[i1 =!= i2, 
          KroneckerDelta[k1, k2] KroneckerDelta[sp1, sp2] 
            KroneckerDelta[\[Alpha]1, \[Alpha]2], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(acmt[
          d, {i1_, k1_, \[Alpha]1_, sp1_}, {i2_, k2_, \[Alpha]2_, 
            sp2_}] := \[IndentingNewLine]If[i1 =!= i2, 
          KroneckerDelta[k1, k2] KroneckerDelta[sp1, sp2] 
            KroneckerDelta[\[Alpha]1, \[Alpha]2], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(acmt[a, {i1_, sp1_}, {i2_, sp2_}] := \[IndentingNewLine]If[
          i1 =!= i2, KroneckerDelta[sp1, sp2], 0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(acmt[b, {i1_, sp1_}, {i2_, sp2_}] := \[IndentingNewLine]If[i1 =!= i2, 
          KroneckerDelta[sp1, sp2], 0];\)\)}], "Input"],

Cell[BoxData[{
    \(SetAttributes[eps, NumericFunction]\), "\[IndentingNewLine]", 
    \(SetAttributes[KroneckerDelta, NumericFunction]\)}], "Input"],

Cell["c is SEA ordered, a and d are EMPTY ordered", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ordering[c] = SEA;\)\), "\[IndentingNewLine]", 
    \(ordering[c] === SEA\), "\[IndentingNewLine]", 
    \(ordering[d] === EMPTY\)}], "Input"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
Unequal operators: always sort cannonically, creation operators to the left, \
etc.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[AN, k, 1, UP]\[CenterDot]d[CR, k, 1, UP]\)], "Input"],

Cell[BoxData[
    \(\(-\((d\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k, \(\(1\)\(\[UpArrow]\)\)\))\)\)\)], "Output"]
}, Open  ]],

Cell["Equal operators with EMPTY ordering", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[AN, 1]\[CenterDot]a[CR, 1]\)], "Input"],

Cell[BoxData[
    \(1 - \(a\_\[UpArrow]\)\^\[Dagger]\[CenterDot]\(a\_\[UpArrow]\)\)], \
"Output"]
}, Open  ]],

Cell["\<\
Equal operators with SEA ordering: limited reordering - since we do not know \
which operators annihilate vacuum (in particular in the case of free \
indexes), we do not attempt to fully normal order the expression with \
\"creation\" operators to the left. Here this ordering would not be of use in \
calculations.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[AN, k, 1, UP]\[CenterDot]c[CR, k, 1, UP]\)], "Input"],

Cell[BoxData[
    \(c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
      c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[AN, k, 1, UP]\[CenterDot]c[CR, k, 1, DO]\)], "Input"],

Cell[BoxData[
    \(\(-\((c\_\(k, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k, \(\(1\)\(\[UpArrow]\)\)\))\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[AN, k, 1, UP]\[CenterDot]c[CR, k, 1, DO]\[CenterDot]
      c[AN, k1, 1, UP]\[CenterDot]c[CR, k1, 1, UP]\)], "Input"],

Cell[BoxData[
    \(\(-\((c\_\(k, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
          c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
          c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger])\)\)\)], "Output"]
}, Open  ]],

Cell["Empty band: creation operators shifted to the left", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d[AN, k, 1, sp1]\[CenterDot]d[CR, k, 1, sp2]\)], "Input"],

Cell[BoxData[
    \(KroneckerDelta[sp1, sp2] - 
      d\_\(k, 1, sp2\)\^\[Dagger]\[CenterDot]d\_\(k, 1, sp1\)\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell["\<\
Let's test improved definition of vev[], which knows more about vacuum \
state\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(vev[
      a\_\[UpArrow]\^\[Dagger]\[CenterDot]
        a\_\[UpArrow]]\), "\[IndentingNewLine]", 
    \(vev[a[AN, 1]\[CenterDot]a[CR, 1]]\)}], "Input"],

Cell[BoxData[
    \(0\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(number[c[k, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(vev[%]\)}], "Input"],

Cell[BoxData[
    \(c\_\(k, \(\(\[Alpha]\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k, \(\(\[Alpha]\)\(\[DownArrow]\)\)\) + 
      c\_\(k, \(\(\[Alpha]\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k, \(\(\[Alpha]\)\(\[UpArrow]\)\)\)\)], "Output"],

Cell[BoxData[
    \(2\ UnitStep[\(-k\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(vev[
      c[CR, k, \[Alpha], \[Sigma]]\[CenterDot]
        c[AN, k, \[Alpha], \[Sigma]]]\), "\[IndentingNewLine]", 
    \(vev[
      c[AN, k, \[Alpha], \[Sigma]]\[CenterDot]
        c[CR, k, \[Alpha], \[Sigma]]]\)}], "Input"],

Cell[BoxData[
    \(UnitStep[\(-k\)]\)], "Output"],

Cell[BoxData[
    \(UnitStep[k]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vev[
      c[CR, k1, \[Alpha], \[Sigma]]\[CenterDot]
        c[AN, k2, \[Alpha], \[Sigma]]]\)], "Input"],

Cell[BoxData[
    \(KroneckerDelta[k1, k2]\ UnitStep[\(-k1\)]\)], "Output"]
}, Open  ]],

Cell["\<\
This one can be shown to be equal to 0: different number of spins!\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c[AN, k, 1, UP]\[CenterDot]c[CR, k, 1, DO]\[CenterDot]
      c[AN, k1, 1, UP]\[CenterDot]c[CR, k1, 1, UP]\), "\[IndentingNewLine]", 
    \(vev[%]\)}], "Input"],

Cell[BoxData[
    \(\(-\((c\_\(k, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
          c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
          c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger])\)\)\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c[AN, k, 1, UP]\[CenterDot]c[CR, k, 1, UP]\[CenterDot]
      c[AN, k1, 1, UP]\[CenterDot]c[CR, k1, 1, UP]\), "\[IndentingNewLine]", 
    \(vev[%]\)}], "Input"],

Cell[BoxData[
    \(c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
      c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\)], "Output"],

Cell[BoxData[
    \(UnitStep[k]\ UnitStep[k1]\)], "Output"]
}, Open  ]],

Cell["This one is more difficult: Wick theorem should be used!", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c[CR, k1, 1, UP]\[CenterDot]c[CR, k2, 1, UP]\[CenterDot]
      c[AN, k1, 1, UP]\[CenterDot]c[AN, k2, 1, UP]\), "\[IndentingNewLine]", 
    \(vev[%]\)}], "Input"],

Cell[BoxData[
    \(c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
      c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
      c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\)], "Output"],

Cell[BoxData[
    \(vev[
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
        c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vev[
      c[CR, k1, \[Alpha], \[Sigma]]\[CenterDot]
        c[AN, k2, \[Alpha], \[Sigma]]\[CenterDot]
        c[CR, k3, \[Alpha], \[Sigma]]\[CenterDot]
        c[AN, k4, \[Alpha], \[Sigma]]]\)], "Input"],

Cell[BoxData[
    \(vev[
      c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \[Alpha], \[Sigma]\)\[CenterDot]
        c\_\(k3, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
        c\_\(k4, \[Alpha], \[Sigma]\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(normalorder[
      c[AN, k, 1, UP]\[CenterDot]c[CR, k, 1, UP]\[CenterDot]
        c[AN, k1, 1, UP]\[CenterDot]
        c[CR, k1, 1, UP]]\), "\[IndentingNewLine]", 
    \(vev[%]\)}], "Input"],

Cell[BoxData[
    \(c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
        c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
        c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger] - 
      UnitStep[k]\ UnitStep[k1]\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 3}],

Cell["Tests of normal ordering", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c[CR, k1, \[Alpha], \[Sigma]]\[CenterDot]
      c[AN, k2, \[Alpha], \[Sigma]]\), "\[IndentingNewLine]", 
    \(normalorder[
      c[CR, k1, \[Alpha], \[Sigma]]\[CenterDot]
        c[AN, k2, \[Alpha], \[Sigma]]]\)}], "Input"],

Cell[BoxData[
    \(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
      c\_\(k2, \[Alpha], \[Sigma]\)\)], "Output"],

Cell[BoxData[
    \(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \[Alpha], \[Sigma]\) - 
      KroneckerDelta[k1, k2]\ UnitStep[\(-k1\)]\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 3}],

Cell["Fermion fields in continuous space", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(psi[\[Alpha]_, \[Sigma]_] = 
      sum[Exp[I\ k\ x] c[AN, k, \[Alpha], \[Sigma]], {k}]\)], "Input"],

Cell[BoxData[
    \(sum[\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\ c\_\(k, \[Alpha], \
\[Sigma]\), {k}]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(NumericQ[x]\), "\[IndentingNewLine]", 
    \(NumericQ[k]\), "\[IndentingNewLine]", 
    \(NumericQ[Exp[I\ k\ x]]\), "\[IndentingNewLine]", 
    \(Conjugate[k] ^= k\), "\[IndentingNewLine]", 
    \(conj[Exp[I\ k\ x]]\)}], "Input"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(k\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(conj[psi[\[Alpha], \[Sigma]]]\)], "Input"],

Cell[BoxData[
    \(sum[\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\ c\_\(k, \[Alpha], \
\[Sigma]\)\^\[Dagger], {k}]\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Editable->False,
  Selectable->False,
  CellFrame->{{0, 0}, {0, 3}},
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {1, 1}},
  CellElementSpacings->{"CellMinHeight"->1},
  CellFrameMargins->False,
  CellFrameColor->RGBColor[0, 0, 1],
  CellSize->{Inherited, 5}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(allpairs[m_, n_] := 
        Flatten[Table[{i, j}, {i, m}, {j, n}], 
          1];\)\), "\[IndentingNewLine]", 
    \(allpairs[2, 2]\)}], "Input"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {2, 1}, {2, 2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Produce\ all\ possible\ pairs\ with\ elements\ taken\ from\ two\ lists\ \
*) \)\(\[IndentingNewLine]\)\(allpairs[{1, 2}, {3, 4}]\)\)\)], "Input"],

Cell[BoxData[
    \({{1, 3}, {1, 4}, {2, 3}, {2, 4}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(x1 = 
      nc[c[CR, k1, \[Alpha], \[Sigma]], c[CR, k2, \[Alpha], \[Sigma]], 
        c[AN, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]]\), "\[IndentingNewLine]", 
    \(FullForm[x1]\), "\[IndentingNewLine]", 
    \(x2 = indecesCR[x1]\), "\[IndentingNewLine]", 
    \(x3 = indecesAN[x1]\), "\[IndentingNewLine]", 
    \(x4 = allpairs[x2, x3]\)}], "Input"],

Cell[BoxData[
    \(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
      c\_\(k2, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
      c\_\(k3, \[Alpha], \[Sigma]\)\[CenterDot]
      c\_\(k4, \[Alpha], \[Sigma]\)\)], "Output"],

Cell[BoxData[
    TagBox[
      StyleBox[\(nc[c[0, k1, \[Alpha], \[Sigma]], 
          c[0, k2, \[Alpha], \[Sigma]], c[1, k3, \[Alpha], \[Sigma]], 
          c[1, k4, \[Alpha], \[Sigma]]]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"],

Cell[BoxData[
    \({1, 2}\)], "Output"],

Cell[BoxData[
    \({3, 4}\)], "Output"],

Cell[BoxData[
    \({{1, 3}, {1, 4}, {2, 3}, {2, 4}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(maxcran[x1]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(disjointQ[{{1, 2}}]\), "\[IndentingNewLine]", 
    \(disjointQ[{{1, 2}, {3, 4}}]\), "\[IndentingNewLine]", 
    \(disjointQ[{{1, 2}, {1, 3}}]\), "\[IndentingNewLine]", 
    \(disjointQ[{{1, 2}, {1, 3}, {1, 4}}]\), "\[IndentingNewLine]", 
    \(disjointQ[{{1, 3}, {1, 4}, {2, 3}}]\)}], "Input"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \(False\)], "Output"],

Cell[BoxData[
    \(False\)], "Output"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      Drop\ 0\ elements\ from\ a\ List\ *) \)\(\[IndentingNewLine]\)\( (*\ 
      dropzeros[l_List] := 
        Delete[l, 
          Position[l, 0, {1}]]\ *) \)\(\[IndentingNewLine]\)\(dropzeros[{0, 
        1, 2, 3, 0, 2, 3, {1}, 0}]\)\)\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 2, 3, {1}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      Generate\ lists\ of\ nr\ pairs\ to\ be\ contracted\ *) \)\(\
\[IndentingNewLine]\)\( (*\ 
      contractedpairs[nr_, l_List] := 
        dropconflicts@KSubsets[l, nr]\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(contractedpairs[1, x4]\), "\[IndentingNewLine]", 
    \(contractedpairs[2, x4]\), "\[IndentingNewLine]", 
    \(contractedpairs[3, x4]\)}], "Input"],

Cell[BoxData[
    \({{{1, 3}}, {{1, 4}}, {{2, 3}}, {{2, 4}}}\)], "Output"],

Cell[BoxData[
    \({{{1, 3}, {2, 4}}, {{1, 4}, {2, 3}}}\)], "Output"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      Contraction\ of\ two\ operators\ according\ to\ standard\ definition\ \
*) \)\(\[IndentingNewLine]\)\( (*\ \(contraction[x1 : op1_[t1_, i1__], 
            x2 : op2_[t2_, i2__]] := \[IndentingNewLine]nc[x1, x2] - 
            normalorder[nc[x1, x2]];\)\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(contraction[c[CR, k, \[Alpha], \[Sigma]], 
      c[AN, kp, \[Alpha]p, \[Sigma]p]]\), "\[IndentingNewLine]", 
    \(contraction[c[AN, k, \[Alpha], \[Sigma]], 
        c[CR, kp, \[Alpha]p, \[Sigma]p]] // Simplify\)}], "Input"],

Cell[BoxData[
    \(KroneckerDelta[k, 
        kp]\ KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Alpha]p, \[Sigma]p}]\ \
UnitStep[\(-k\)]\)], "Output"],

Cell[BoxData[
    \(KroneckerDelta[k, 
        kp]\ \((\(-KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Alpha]p, \
\[Sigma]p}]\)\ UnitStep[\(-kp\)] + 
          KroneckerDelta[\[Alpha], \[Alpha]p]\ vev[
              KroneckerDelta[\[Sigma], \[Sigma]p]])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(contractone[{1, 1, {aa, bb, cc, dd}}, {1, 
        3}]\[IndentingNewLine]
    contractone[{1, 
        1, {c[CR, k, \[Alpha], \[Sigma]], c[AN, k, \[Alpha], \[Sigma]]}}, {1, 
        2}]\)\)\)], "Input"],

Cell[BoxData[
    \({2, contraction[aa, cc], {1, bb, 1, dd}}\)], "Output"],

Cell[BoxData[
    \({2, UnitStep[\(-k\)], {1, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(remainder[{2, 2, a[CR, \[Sigma]], 1, 1}]\), "\[IndentingNewLine]", 
    \(remainder[{2, 1}]\), "\[IndentingNewLine]", 
    \(remainder[{1, 1}]\), "\[IndentingNewLine]", 
    \(remainder[{2, 2, 1, 1}]\), "\[IndentingNewLine]", 
    \(remainder[{2, 1, 1}]\), "\[IndentingNewLine]", 
    \(remainder[{4, 3, 2, 1}]\)}], "Input"],

Cell[BoxData[
    \(\(\(\[Therefore]\)\(\(a\_\[Sigma]\^\[Dagger]\)\(\[Therefore]\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(-1\)\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(contract[{a[AN, \[Sigma]], 
        a[CR, \[Sigma]]}, {{1, 2}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k, \[Alpha], \[Sigma]], 
        c[AN, k, \[Alpha], \[Sigma]]}, {{1, 2}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[AN, k2, \[Alpha], \[Sigma]], 
        c[CR, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 2}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[AN, k2, \[Alpha], \[Sigma]], 
        c[CR, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 2}, {3, 
          4}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[AN, k2, \[Alpha], \[Sigma]], 
        c[CR, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 4}, {3, 
          2}}]\[IndentingNewLine] (*\ 
      This\ one\ should\ be\ familiar ... \ *) \), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[CR, k2, \[Alpha], \[Sigma]], 
        c[AN, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 3}, {2, 
          4}}]\), "\[IndentingNewLine]", 
    \(contract[{c[CR, k1, \[Alpha], \[Sigma]], c[CR, k2, \[Alpha], \[Sigma]], 
        c[AN, k3, \[Alpha], \[Sigma]], 
        c[AN, k4, \[Alpha], \[Sigma]]}, {{1, 4}, {2, 3}}]\)}], "Input"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    \(UnitStep[\(-k\)]\)], "Output"],

Cell[BoxData[
    \(\((\(\[Therefore]\)\(\(c\_\(k3, \[Alpha], \[Sigma]\)\^\[Dagger]\
\[CenterDot]
              c\_\(k4, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k1, k2]\ UnitStep[\(-k1\)]\)], "Output"],

Cell[BoxData[
    \(KroneckerDelta[k1, k2]\ KroneckerDelta[k3, 
        k4]\ UnitStep[\(-k1\)]\ UnitStep[\(-k3\)]\)], "Output"],

Cell[BoxData[
    \(KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
        k3]\ UnitStep[\(-k1\)]\ UnitStep[\(-k3\)]\)], "Output"],

Cell[BoxData[
    \(\(-KroneckerDelta[k1, k3]\)\ KroneckerDelta[k2, 
        k4]\ UnitStep[\(-k1\)]\ UnitStep[\(-k2\)]\)], "Output"],

Cell[BoxData[
    \(KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
        k3]\ UnitStep[\(-k1\)]\ UnitStep[\(-k2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(x1\), "\[IndentingNewLine]", 
    \(wickorder[0, x1]\), "\[IndentingNewLine]", 
    \(wickorder[1, x1]\), "\[IndentingNewLine]", 
    \(wickorder[2, x1] // Simplify\)}], "Input"],

Cell[BoxData[
    \(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
      c\_\(k2, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
      c\_\(k3, \[Alpha], \[Sigma]\)\[CenterDot]
      c\_\(k4, \[Alpha], \[Sigma]\)\)], "Output"],

Cell[BoxData[
    \(\(\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\
\[CenterDot]c\_\(k2, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
          c\_\(k3, \[Alpha], \[Sigma]\)\[CenterDot]
          c\_\(k4, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\((\(\[Therefore]\)\(\(c\_\(k2, \[Alpha], \[Sigma]\)\^\[Dagger]\
\[CenterDot]
                  c\_\(k4, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\)\ \
KroneckerDelta[k1, 
          k3]\ UnitStep[\(-k1\)] + \((\(\[Therefore]\)\(\(c\_\(k2, \[Alpha], \
\[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k3, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k1, 
          k4]\ UnitStep[\(-k1\)] + \((\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \
\[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k4, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k2, 
          k3]\ UnitStep[\(-k2\)] - \((\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \
\[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k3, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k2, k4]\ UnitStep[\(-k2\)]\)], "Output"],

Cell[BoxData[
    \(\((KroneckerDelta[k1, k4]\ KroneckerDelta[k2, k3] - 
          KroneckerDelta[k1, k3]\ KroneckerDelta[k2, 
              k4])\)\ UnitStep[\(-k1\)]\ UnitStep[\(-k2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c[CR, k1, 1, UP]\[CenterDot]c[CR, k2, 1, UP]\[CenterDot]
      c[AN, k1, 1, UP]\[CenterDot]c[AN, k2, 1, UP]\), "\[IndentingNewLine]", 
    \(wickorder[2, %] // Simplify\)}], "Input"],

Cell[BoxData[
    \(c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
      c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
      c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\)], "Output"],

Cell[BoxData[
    \(\((\(-1\) + 
          KroneckerDelta[k1, k2]\^2)\)\ UnitStep[\(-k1\)]\ \
UnitStep[\(-k2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(-c[AN, k, 1, UP]\)\[CenterDot]c[CR, k, 1, DO]\[CenterDot]
      c[AN, k1, 1, UP]\[CenterDot]c[CR, k1, 1, UP]\), "\[IndentingNewLine]", 
    \(wickorder[2, %]\)}], "Input"],

Cell[BoxData[
    \(c\_\(k, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
      c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\)], "Output"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wick[
      c[AN, k, 1, UP]\[CenterDot]c[CR, k, 1, UP]\[CenterDot]
        c[AN, k1, 1, UP]\[CenterDot]c[CR, k1, 1, UP]]\)], "Input"],

Cell[BoxData[
    \(\((\(\[Therefore]\)\(\(c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
              c\_\(k, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
              c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
              c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\)\(\[Therefore]\)\
\))\) + \((\(\[Therefore]\)\(\(c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
                c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\)\(\[Therefore]\
\)\))\)\ UnitStep[\(-k\)] + \((\(\[Therefore]\)\(\(c\_\(k, \
\(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
                c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\)\(\[Therefore]\
\)\))\)\ KroneckerDelta[k, 
          k1]\ UnitStep[\(-k\)] + \((\(\[Therefore]\)\(\(c\_\(k, \(\(1\)\(\
\[UpArrow]\)\)\)\[CenterDot]
                c\_\(k, \
\(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\)\(\[Therefore]\)\))\)\ \
UnitStep[\(-k1\)] + \((\(\[Therefore]\)\(\(c\_\(k, \
\(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
                c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k, k1]\ UnitStep[\(-k1\)] + 
      UnitStep[\(-k\)]\ UnitStep[\(-k1\)] + 
      KroneckerDelta[k, k1]\^2\ UnitStep[\(-k\)]\ UnitStep[\(-k1\)]\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wick[
      c[CR, k1, \[Alpha], \[Sigma]]\[CenterDot]
        c[AN, k2, \[Alpha], \[Sigma]]\[CenterDot]
        c[CR, k3, \[Alpha], \[Sigma]]\[CenterDot]
        c[AN, k4, \[Alpha], \[Sigma]]]\)], "Input"],

Cell[BoxData[
    \(\((\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\
\[CenterDot]c\_\(k2, \[Alpha], \[Sigma]\)\[CenterDot]
              c\_\(k3, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
              c\_\(k4, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\) + \((\(\
\[Therefore]\)\(\(c\_\(k3, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k4, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k1, 
          k2]\ UnitStep[\(-k1\)] + \((\(\[Therefore]\)\(\(c\_\(k2, \[Alpha], \
\[Sigma]\)\[CenterDot]
                c\_\(k3, \[Alpha], \[Sigma]\)\^\[Dagger]\)\(\[Therefore]\)\))\
\)\ KroneckerDelta[k1, 
          k4]\ UnitStep[\(-k1\)] + \((\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \
\[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k4, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k2, 
          k3]\ UnitStep[\(-k3\)] + \((\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \
\[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k2, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k3, k4]\ UnitStep[\(-k3\)] + 
      KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
          k3]\ UnitStep[\(-k1\)]\ UnitStep[\(-k3\)] + 
      KroneckerDelta[k1, k2]\ KroneckerDelta[k3, 
          k4]\ UnitStep[\(-k1\)]\ UnitStep[\(-k3\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wick[
        c[CR, k1, \[Alpha], \[Sigma]]\[CenterDot]
          c[AN, k2, \[Alpha], \[Sigma]]\[CenterDot]
          c[CR, k3, \[Alpha], \[Tau]]\[CenterDot]
          c[AN, k4, \[Alpha], \[Tau]]] // Expand\)], "Input"],

Cell[BoxData[
    \(\(-\((\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\
\[CenterDot]c\_\(k3, \[Alpha], \[Tau]\)\^\[Dagger]\[CenterDot]
                c\_\(k2, \[Alpha], \[Sigma]\)\[CenterDot]
                c\_\(k4, \[Alpha], \[Tau]\)\)\(\[Therefore]\)\))\)\) + \((\(\
\[Therefore]\)\(\(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k4, \[Alpha], \[Tau]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k2, 
          k3]\ KroneckerDelta[\[Sigma], \[Tau]] + \
\((\(\[Therefore]\)\(\(c\_\(k3, \[Alpha], \[Tau]\)\^\[Dagger]\[CenterDot]
                c\_\(k4, \[Alpha], \[Tau]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k1, 
          k2]\ UnitStep[\(-k1\)] - \((\(\[Therefore]\)\(\(c\_\(k3, \[Alpha], \
\[Tau]\)\^\[Dagger]\[CenterDot]
                c\_\(k2, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k1, 
          k4]\ KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Alpha], \[Tau]}]\ \
UnitStep[\(-k1\)] + 
      KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
          k3]\ KroneckerDelta[\[Sigma], \[Tau]]\ KroneckerDelta[{\[Alpha], \
\[Sigma]}, {\[Alpha], \[Tau]}]\ UnitStep[\(-k1\)] + \
\((\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k2, \[Alpha], \[Sigma]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k3, 
          k4]\ UnitStep[\(-k3\)] - \((\(\[Therefore]\)\(\(c\_\(k1, \[Alpha], \
\[Sigma]\)\^\[Dagger]\[CenterDot]
                c\_\(k4, \[Alpha], \[Tau]\)\)\(\[Therefore]\)\))\)\ \
KroneckerDelta[k2, 
          k3]\ KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Alpha], \[Tau]}]\ \
UnitStep[\(-k3\)] + 
      KroneckerDelta[k1, k2]\ KroneckerDelta[k3, 
          k4]\ UnitStep[\(-k1\)]\ UnitStep[\(-k3\)] - 
      KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
          k3]\ KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Alpha], \[Tau]}]\^2\ \
UnitStep[\(-k1\)]\ UnitStep[\(-k3\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(y1 = 
      normalorder[
        c[CR, k1, \[Alpha], \[Sigma]]\[CenterDot]
          c[AN, k2, \[Alpha], \[Sigma]]]\), "\[IndentingNewLine]", 
    \(y2 = 
      normalorder[
        c[CR, k3, \[Beta], \[Tau]]\[CenterDot]
          c[AN, k4, \[Beta], \[Tau]]]\)}], "Input"],

Cell[BoxData[
    \(c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \[Alpha], \[Sigma]\) - 
      KroneckerDelta[k1, k2]\ UnitStep[\(-k1\)]\)], "Output"],

Cell[BoxData[
    \(c\_\(k3, \[Beta], \[Tau]\)\^\[Dagger]\[CenterDot]
        c\_\(k4, \[Beta], \[Tau]\) - 
      KroneckerDelta[k3, k4]\ UnitStep[\(-k3\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(y3 = y1\[CenterDot]y2\), "\[IndentingNewLine]", 
    \(y4 = vevwick[y3]\)}], "Input"],

Cell[BoxData[
    \(KroneckerDelta[k2, 
          k3]\ KroneckerDelta[\[Alpha], \[Beta]]\ KroneckerDelta[\[Sigma], \
\[Tau]]\ c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
          c\_\(k4, \[Beta], \[Tau]\) - 
      c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \[Beta], \[Tau]\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \[Alpha], \[Sigma]\)\[CenterDot]c\_\(k4, \[Beta], \[Tau]\) - 
      KroneckerDelta[k3, 
          k4]\ c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
          c\_\(k2, \[Alpha], \[Sigma]\)\ UnitStep[\(-k3\)] - 
      KroneckerDelta[k1, 
          k2]\ UnitStep[\(-k1\)]\ \((c\_\(k3, \[Beta], \[Tau]\)\^\[Dagger]\
\[CenterDot]c\_\(k4, \[Beta], \[Tau]\) - 
            KroneckerDelta[k3, k4]\ UnitStep[\(-k3\)])\)\)], "Output"],

Cell[BoxData[
    \(KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
          k3]\ KroneckerDelta[\[Alpha], \[Beta]]\ KroneckerDelta[\[Sigma], \
\[Tau]]\ KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Beta], \[Tau]}]\ \
UnitStep[\(-k1\)] - 
      KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
          k3]\ KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Beta], \[Tau]}]\^2\ \
UnitStep[\(-k1\)]\ UnitStep[\(-k3\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(y5 = Simplify[y3 - y4]\)], "Input"],

Cell[BoxData[
    \(KroneckerDelta[k2, 
          k3]\ KroneckerDelta[\[Alpha], \[Beta]]\ KroneckerDelta[\[Sigma], \
\[Tau]]\ c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
          c\_\(k4, \[Beta], \[Tau]\) - 
      c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \[Beta], \[Tau]\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \[Alpha], \[Sigma]\)\[CenterDot]c\_\(k4, \[Beta], \[Tau]\) - 
      KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
          k3]\ KroneckerDelta[\[Alpha], \[Beta]]\ KroneckerDelta[\[Sigma], \
\[Tau]]\ KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Beta], \[Tau]}]\ \
UnitStep[\(-k1\)] - 
      KroneckerDelta[k3, 
          k4]\ c\_\(k1, \[Alpha], \[Sigma]\)\^\[Dagger]\[CenterDot]
          c\_\(k2, \[Alpha], \[Sigma]\)\ UnitStep[\(-k3\)] + 
      KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
          k3]\ KroneckerDelta[{\[Alpha], \[Sigma]}, {\[Beta], \[Tau]}]\^2\ \
UnitStep[\(-k1\)]\ UnitStep[\(-k3\)] - 
      KroneckerDelta[k1, 
          k2]\ UnitStep[\(-k1\)]\ \((c\_\(k3, \[Beta], \[Tau]\)\^\[Dagger]\
\[CenterDot]c\_\(k4, \[Beta], \[Tau]\) - 
            KroneckerDelta[k3, k4]\ UnitStep[\(-k3\)])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
      y5, {\[Alpha], 1, 2}, {\[Beta], 1, 2}, {\[Sigma], 0, 1}, {\[Tau], 0, 
        1}]\)], "Input"],

Cell[BoxData[
    \(KroneckerDelta[k2, 
          k3]\ c\_\(k1, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k4, \(\(1\)\(\[DownArrow]\)\)\) + 
      KroneckerDelta[k2, 
          k3]\ c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k4, \(\(1\)\(\[UpArrow]\)\)\) + 
      KroneckerDelta[k2, 
          k3]\ c\_\(k1, \(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k4, \(\(2\)\(\[DownArrow]\)\)\) + 
      KroneckerDelta[k2, 
          k3]\ c\_\(k1, \(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k4, \(\(2\)\(\[UpArrow]\)\)\) - 
      c\_\(k1, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[DownArrow]\)\)\)\[CenterDot]
        c\_\(k4, \(\(1\)\(\[DownArrow]\)\)\) - 
      c\_\(k1, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[DownArrow]\)\)\)\[CenterDot]
        c\_\(k4, \(\(1\)\(\[UpArrow]\)\)\) - 
      c\_\(k1, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[DownArrow]\)\)\)\[CenterDot]
        c\_\(k4, \(\(2\)\(\[DownArrow]\)\)\) - 
      c\_\(k1, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[DownArrow]\)\)\)\[CenterDot]
        c\_\(k4, \(\(2\)\(\[UpArrow]\)\)\) - 
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
        c\_\(k4, \(\(1\)\(\[DownArrow]\)\)\) - 
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
        c\_\(k4, \(\(1\)\(\[UpArrow]\)\)\) - 
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]
        c\_\(k4, \(\(2\)\(\[DownArrow]\)\)\) - 
      c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k3, \(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
        c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\[CenterDot]c\_\(k4, \(\(2\)\(\
\[UpArrow]\)\)\) - 
      c\_\(k1, \(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k3, \
\(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \(\(2\)\(\
\[DownArrow]\)\)\)\[CenterDot]c\_\(k4, \(\(1\)\(\[DownArrow]\)\)\) - 
      c\_\(k1, \(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k3, \
\(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \
\(\(2\)\(\[DownArrow]\)\)\)\[CenterDot]c\_\(k4, \(\(1\)\(\[UpArrow]\)\)\) - 
      c\_\(k1, \(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k3, \
\(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \(\(2\)\(\
\[DownArrow]\)\)\)\[CenterDot]c\_\(k4, \(\(2\)\(\[DownArrow]\)\)\) - 
      c\_\(k1, \(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k3, \
\(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \
\(\(2\)\(\[DownArrow]\)\)\)\[CenterDot]c\_\(k4, \(\(2\)\(\[UpArrow]\)\)\) - 
      c\_\(k1, \(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k3, \(\(1\
\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \(\(2\)\(\[UpArrow]\)\)\
\)\[CenterDot]c\_\(k4, \(\(1\)\(\[DownArrow]\)\)\) - 
      c\_\(k1, \(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k3, \(\(1\
\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \(\(2\)\(\[UpArrow]\)\)\)\
\[CenterDot]c\_\(k4, \(\(1\)\(\[UpArrow]\)\)\) - 
      c\_\(k1, \(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k3, \(\(2\
\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \(\(2\)\(\[UpArrow]\)\)\
\)\[CenterDot]c\_\(k4, \(\(2\)\(\[DownArrow]\)\)\) - 
      c\_\(k1, \(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k3, \(\(2\
\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \(\(2\)\(\[UpArrow]\)\)\)\
\[CenterDot]c\_\(k4, \(\(2\)\(\[UpArrow]\)\)\) - 
      4\ KroneckerDelta[k1, k4]\ KroneckerDelta[k2, k3]\ UnitStep[\(-k1\)] - 
      4\ KroneckerDelta[k3, 
          k4]\ c\_\(k1, \(\(1\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k2, \(\(1\)\(\[DownArrow]\)\)\)\ UnitStep[\(-k3\)] - 
      4\ KroneckerDelta[k3, 
          k4]\ c\_\(k1, \(\(1\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]
          c\_\(k2, \(\(1\)\(\[UpArrow]\)\)\)\ UnitStep[\(-k3\)] - 
      4\ KroneckerDelta[k3, 
          k4]\ c\_\(k1, \(\(2\)\(\[DownArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\
\(k2, \(\(2\)\(\[DownArrow]\)\)\)\ UnitStep[\(-k3\)] - 
      4\ KroneckerDelta[k3, 
          k4]\ c\_\(k1, \
\(\(2\)\(\[UpArrow]\)\)\)\^\[Dagger]\[CenterDot]c\_\(k2, \
\(\(2\)\(\[UpArrow]\)\)\)\ UnitStep[\(-k3\)] + 
      4\ KroneckerDelta[k1, k4]\ KroneckerDelta[k2, 
          k3]\ UnitStep[\(-k1\)]\ UnitStep[\(-k3\)] - 
      4\ KroneckerDelta[k1, 
          k2]\ UnitStep[\(-k1\)]\ \((c\_\(k3, \(\(1\)\(\[DownArrow]\)\)\)\^\
\[Dagger]\[CenterDot]c\_\(k4, \(\(1\)\(\[DownArrow]\)\)\) - 
            KroneckerDelta[k3, k4]\ UnitStep[\(-k3\)])\) - 
      4\ KroneckerDelta[k1, 
          k2]\ UnitStep[\(-k1\)]\ \((c\_\(k3, \(\(1\)\(\[UpArrow]\)\)\)\^\
\[Dagger]\[CenterDot]c\_\(k4, \(\(1\)\(\[UpArrow]\)\)\) - 
            KroneckerDelta[k3, k4]\ UnitStep[\(-k3\)])\) - 
      4\ KroneckerDelta[k1, 
          k2]\ UnitStep[\(-k1\)]\ \((c\_\(k3, \(\(2\)\(\[DownArrow]\)\)\)\^\
\[Dagger]\[CenterDot]c\_\(k4, \(\(2\)\(\[DownArrow]\)\)\) - 
            KroneckerDelta[k3, k4]\ UnitStep[\(-k3\)])\) - 
      4\ KroneckerDelta[k1, 
          k2]\ UnitStep[\(-k1\)]\ \((c\_\(k3, \(\(2\)\(\[UpArrow]\)\)\)\^\
\[Dagger]\[CenterDot]c\_\(k4, \(\(2\)\(\[UpArrow]\)\)\) - 
            KroneckerDelta[k3, k4]\ UnitStep[\(-k3\)])\)\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1600}, {0, 1200}},
WindowSize->{598, 906},
WindowMargins->{{Automatic, 114}, {Automatic, 102}},
Visible->True,
ShowSelection->True,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {10, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{27, 10}, {10, 30}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "SlideShow"]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-.074999999999999997, -.085000000000000006}, {
                0, 0}}, BoxBaselineShift -> .5], "X"}]], "mma"->"Mathematica",
         "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{27, 10}, {20, 2}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "SlideShow"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {8, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "SlideShow"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{27, Inherited}, {8, 34}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->4,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 2},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "SlideShow"]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "SlideShow"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{60, Inherited}, {2, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "SlideShow"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{60, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "SlideShow"]],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{60, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "SlideShow"]],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{66, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "SlideShow"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["InputOnly", "SlideShow"]],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{66, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "SlideShow"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "SlideShow"]],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "SlideShow"]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "SlideShow"]],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.269993, 0.308507, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "SlideShow"]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "SlideShow"]],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Inert"],
    StyleMenuListing->None,
    Background->RGBColor[0.870588, 0.905882, 0.972549]],
  
  Cell[StyleData["Inert", "Printout"],
    StyleMenuListing->None,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "SlideShow"]],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "SlideShow"]],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{60, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "SlideShow"]],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{60, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    CounterAssignments->{{"Outline2", 0}, {"Outline3", 0}, {"Outline4", 0}},
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "SlideShow"]],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{90, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    CounterAssignments->{{"Outline3", 0}, {"Outline4", 0}},
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "SlideShow"]],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{120, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    CounterAssignments->{{"Outline4", 0}},
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "SlideShow"]],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{150, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "SlideShow"]],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "SlideShow"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "SlideShow"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display of certain \
types of objects in typeset expressions.  For example, \"UnmatchedBracket\" \
style defines how unmatched bracket, curly bracket, and parenthesis \
characters are displayed (typically by coloring them to make them stand out).\
\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]],
  
  Cell[StyleData["Completions"],
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 24}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "SlideShow"]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{39, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ObjectName", "SlideShow"]],
  
  Cell[StyleData["ObjectName", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "SlideShow"]],
  
  Cell[StyleData["Usage", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "SlideShow"]],
  
  Cell[StyleData["Notes", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineOutput", "SlideShow"]],
  
  Cell[StyleData["InlineOutput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "SlideShow"]],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "SlideShow"]],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "SlideShow"]],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "SlideShow"]],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "SlideShow"]],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "SlideShow"]],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "SlideShow"]],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "SlideShow"]],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "SlideShow"]],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "SlideShow"]],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "SlideShow"]],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "SlideShow"]],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "SlideShow"]],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "SlideShow"]],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "SlideShow"]],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "SlideShow"]],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "SlideShow"]],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "SlideShow"]],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "SlideShow"]],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "SlideShow"]],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "SlideShow"]],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "SlideShow"]],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "SlideShow"]],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "SlideShow"]],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "SlideShow"]],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "SlideShow"]],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"]],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{20, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{14, 10}, {6, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 84, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[1863, 58, 51, 1, 27, "Input"],
Cell[1917, 61, 92, 1, 23, "Print"],
Cell[2012, 64, 81, 1, 23, "Print"],
Cell[2096, 67, 104, 2, 27, "Output"]
}, Open  ]],
Cell[2215, 72, 55, 1, 27, "Input"],
Cell[2273, 75, 193, 4, 50, "Text"],
Cell[2469, 81, 8876, 207, 475, "Input"],
Cell[11348, 290, 291, 5, 75, "Input"],
Cell[11642, 297, 58, 1, 27, "Input"],
Cell[11703, 300, 371, 7, 75, "Input"],
Cell[12077, 309, 31, 0, 32, "Text"],
Cell[12111, 311, 973, 19, 219, "Input"],
Cell[13087, 332, 150, 2, 43, "Input"],
Cell[13240, 336, 59, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[13324, 340, 165, 3, 59, "Input"],
Cell[13492, 345, 38, 1, 27, "Output"],
Cell[13533, 348, 38, 1, 27, "Output"]
}, Open  ]],
Cell[13586, 352, 107, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[13718, 359, 75, 1, 27, "Input"],
Cell[13796, 362, 145, 2, 29, "Output"]
}, Open  ]],
Cell[13956, 367, 51, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[14032, 371, 61, 1, 27, "Input"],
Cell[14096, 374, 97, 2, 29, "Output"]
}, Open  ]],
Cell[14208, 379, 339, 6, 86, "Text"],

Cell[CellGroupData[{
Cell[14572, 389, 75, 1, 27, "Input"],
Cell[14650, 392, 130, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14817, 399, 75, 1, 27, "Input"],
Cell[14895, 402, 147, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15079, 409, 138, 2, 27, "Input"],
Cell[15220, 413, 272, 4, 29, "Output"]
}, Open  ]],
Cell[15507, 420, 66, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[15598, 424, 77, 1, 27, "Input"],
Cell[15678, 427, 123, 2, 30, "Output"]
}, Open  ]],
Cell[15816, 432, 283, 9, 10, "Text"],
Cell[16102, 443, 102, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[16229, 450, 172, 4, 48, "Input"],
Cell[16404, 456, 35, 1, 27, "Output"],
Cell[16442, 459, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16514, 465, 97, 2, 43, "Input"],
Cell[16614, 469, 272, 4, 29, "Output"],
Cell[16889, 475, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16979, 481, 247, 6, 43, "Input"],
Cell[17229, 489, 50, 1, 27, "Output"],
Cell[17282, 492, 45, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17364, 498, 124, 3, 27, "Input"],
Cell[17491, 503, 75, 1, 27, "Output"]
}, Open  ]],
Cell[17581, 507, 90, 2, 32, "Text"],

Cell[CellGroupData[{
Cell[17696, 513, 180, 3, 43, "Input"],
Cell[17879, 518, 272, 4, 29, "Output"],
Cell[18154, 524, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18226, 530, 180, 3, 43, "Input"],
Cell[18409, 535, 247, 4, 29, "Output"],
Cell[18659, 541, 59, 1, 27, "Output"]
}, Open  ]],
Cell[18733, 545, 72, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[18830, 549, 182, 3, 43, "Input"],
Cell[19015, 554, 249, 4, 29, "Output"],
Cell[19267, 560, 267, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19571, 570, 224, 5, 27, "Input"],
Cell[19798, 577, 247, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20082, 587, 211, 5, 59, "Input"],
Cell[20296, 594, 288, 5, 29, "Output"],
Cell[20587, 601, 35, 1, 27, "Output"]
}, Open  ]],
Cell[20637, 605, 285, 9, 5, "Text"],
Cell[20925, 616, 40, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[20990, 620, 245, 5, 43, "Input"],
Cell[21238, 627, 122, 2, 29, "Output"],
Cell[21363, 631, 175, 3, 29, "Output"]
}, Open  ]],
Cell[21553, 637, 285, 9, 5, "Text"],
Cell[21841, 648, 50, 0, 32, "Text"],

Cell[CellGroupData[{
Cell[21916, 652, 119, 2, 27, "Input"],
Cell[22038, 656, 116, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22191, 663, 250, 5, 91, "Input"],
Cell[22444, 670, 38, 1, 27, "Output"],
Cell[22485, 673, 38, 1, 27, "Output"],
Cell[22526, 676, 38, 1, 27, "Output"],
Cell[22567, 679, 35, 1, 27, "Output"],
Cell[22605, 682, 79, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22721, 688, 62, 1, 27, "Input"],
Cell[22786, 691, 132, 2, 32, "Output"]
}, Open  ]],
Cell[22933, 696, 283, 9, 10, "Text"],

Cell[CellGroupData[{
Cell[23241, 709, 169, 4, 43, "Input"],
Cell[23413, 715, 66, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23516, 721, 181, 3, 43, "Input"],
Cell[23700, 726, 66, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23803, 732, 396, 8, 107, "Input"],
Cell[24202, 742, 229, 4, 29, "Output"],
Cell[24434, 748, 282, 7, 40, "Output"],
Cell[24719, 757, 40, 1, 27, "Output"],
Cell[24762, 760, 40, 1, 27, "Output"],
Cell[24805, 763, 66, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24908, 769, 44, 1, 27, "Input"],
Cell[24955, 772, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25027, 778, 314, 5, 91, "Input"],
Cell[25344, 785, 38, 1, 27, "Output"],
Cell[25385, 788, 38, 1, 27, "Output"],
Cell[25426, 791, 39, 1, 27, "Output"],
Cell[25468, 794, 39, 1, 27, "Output"],
Cell[25510, 797, 39, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25586, 803, 281, 6, 59, "Input"],
Cell[25870, 811, 54, 1, 27, "Output"]
}, Open  ]],
Cell[25939, 815, 224, 5, 43, "Input"],

Cell[CellGroupData[{
Cell[26188, 824, 169, 3, 59, "Input"],
Cell[26360, 829, 74, 1, 27, "Output"],
Cell[26437, 832, 70, 1, 27, "Output"],
Cell[26510, 835, 36, 1, 27, "Output"]
}, Open  ]],
Cell[26561, 839, 310, 5, 59, "Input"],

Cell[CellGroupData[{
Cell[26896, 848, 245, 4, 43, "Input"],
Cell[27144, 854, 146, 3, 27, "Output"],
Cell[27293, 859, 264, 5, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27594, 869, 249, 5, 59, "Input"],
Cell[27846, 876, 74, 1, 27, "Output"],
Cell[27923, 879, 63, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28023, 885, 345, 6, 107, "Input"],
Cell[28371, 893, 102, 2, 29, "Output"],
Cell[28476, 897, 40, 1, 27, "Output"],
Cell[28519, 900, 35, 1, 27, "Output"],
Cell[28557, 903, 35, 1, 27, "Output"],
Cell[28595, 906, 35, 1, 27, "Output"],
Cell[28633, 909, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28705, 915, 1338, 23, 219, "Input"],
Cell[30046, 940, 35, 1, 27, "Output"],
Cell[30084, 943, 50, 1, 27, "Output"],
Cell[30137, 946, 223, 4, 29, "Output"],
Cell[30363, 952, 127, 2, 43, "Output"],
Cell[30493, 956, 127, 2, 43, "Output"],
Cell[30623, 960, 132, 2, 43, "Output"],
Cell[30758, 964, 127, 2, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30922, 971, 199, 4, 75, "Input"],
Cell[31124, 977, 229, 4, 29, "Output"],
Cell[31356, 983, 276, 4, 29, "Output"],
Cell[31635, 989, 847, 16, 83, "Output"],
Cell[32485, 1007, 199, 3, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32721, 1015, 203, 3, 43, "Input"],
Cell[32927, 1020, 249, 4, 29, "Output"],
Cell[33179, 1026, 125, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33341, 1034, 194, 3, 43, "Input"],
Cell[33538, 1039, 249, 4, 29, "Output"],
Cell[33790, 1045, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33862, 1051, 153, 3, 43, "Input"],
Cell[34018, 1056, 1208, 21, 117, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35263, 1082, 225, 5, 27, "Input"],
Cell[35491, 1089, 1305, 23, 149, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36833, 1117, 239, 5, 43, "Input"],
Cell[37075, 1124, 1894, 34, 233, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39006, 1163, 293, 8, 43, "Input"],
Cell[39302, 1173, 175, 3, 29, "Output"],
Cell[39480, 1178, 169, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39686, 1186, 106, 2, 43, "Input"],
Cell[39795, 1190, 785, 14, 97, "Output"],
Cell[40583, 1206, 407, 7, 77, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41027, 1218, 55, 1, 27, "Input"],
Cell[41085, 1221, 1168, 21, 163, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42290, 1247, 125, 3, 27, "Input"],
Cell[42418, 1252, 5943, 100, 467, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

